import urllib.parse

import aiohttp


class HttpError(Exception):
    def __init__(self, msg, response):
        self.response = response
        super().__init__(msg)


class Client:
    def __init__(self, token):
        self.token = token
        self.session = aiohttp.ClientSession()
        self.baseurl = 'https://control.heavynode.com/api'

    async def make_request(self, method, path, *args, **kwargs):
        h = {'Authorization': f'Bearer {self.token}'}
        if 'headers' in kwargs:
            kwargs['headers'].update(h)
        else:
            kwargs['headers'] = h

        if path[0] != '/': 
            path = '/' + path
        url = self.baseurl + path

        r = await self.session.request(method, url, *args, **kwargs)
        if r.status >= 400:
            raise HttpError(f'Request failed with status code {r.status}', r)
        return r

    async def send_command(self, serverid, cmd):
        payload = {'command': cmd}
        return await self.make_request('POST', f'/client/servers/{serverid}/command', json=payload)
